# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`pcp`](#pcp): Manage PCP

_Private Classes_

* `pcp::config`: 
* `pcp::install`: 
* `pcp::repo`: 
* `pcp::resources`: 
* `pcp::service`: 
* `pcp::user`: 

**Defined types**

* [`pcp::pmda`](#pcppmda): Install, enable and optionally configure a PMDA
* [`pcp::pmie`](#pcppmie): Configure a pmie
* [`pcp::pmlogger`](#pcppmlogger): Configure a pmlogger

## Classes

### pcp

Manage PCP

#### Examples

##### 

```puppet
include ::pcp
```

#### Parameters

The following parameters are available in the `pcp` class.

##### `ensure`

Data type: `Enum['running', 'stopped', 'absent']`

Defines state of PCP.
Valid values are `running`, `stopped`, or `absent`.
Default is `running`.

Default value: 'running'

##### `manage_repo`

Data type: `Boolean`

Determines if PCP repo should be managed.
Default is `true`.

Default value: `true`

##### `repo_baseurl`

Data type: `Optional[String]`

Base URL to pcp yum repo.
Default is `https://dl.bintray.com/pcp/el%{::operatingsystemmajrelease}`.

Default value: `undef`

##### `repo_exclude`

Data type: `Optional[String]`

Packages to exclude from PCP repo

Default value: `undef`

##### `package_ensure`

Data type: `String`

Package ensure property.
Value is set to absent if `ensure` is `absent`.
Default is `present`.

Default value: 'present'

##### `package_name`

Data type: `String`

Name of PCP package.
Default is `pcp`.

Default value: 'pcp'

##### `extra_packages`

Data type: `Array`

Array of extra packages to install for PCP

Default value: []

##### `service_ensure`

Data type: `Optional[String]`

Set service ensure property for `pmcd`, `pmie` and `pmlogger` services.
Default is based on `ensure` parameter.

Default value: `undef`

##### `service_enable`

Data type: `Optional[Boolean]`

Set service enable property for `pmcd`, `pmie` and `pmlogger` services.
Default is based on `ensure` parameter.

Default value: `undef`

##### `enable_pmproxy`

Data type: `Boolean`

Boolean that determines if pmproxy service is running/enabled.
Default is `false`.

Default value: `false`

##### `manage_user`

Data type: `Boolean`

Boolean that sets if pcp user / group is managed.
Default is `true`.

Default value: `true`

##### `pcp_group_gid`

Data type: `Optional[Integer]`

pcp group GID.
Default is `undef`.

Default value: `undef`

##### `pcp_user_uid`

Data type: `Optional[Integer]`

pcp user UID.
Default is `undef`.

Default value: `undef`

##### `cron_ensure`

Data type: `Optional[String]`

Ensure passed to cron files.
Default based on value of `ensure`.

Default value: `undef`

##### `pmlogger_cron_template`

Data type: `String`

Template used for pmlogger cron.
Default is `pcp/pcp-pmlogger.cron.erb`.

Default value: 'pcp/pcp-pmlogger.cron.erb'

##### `pmie_cron_template`

Data type: `String`

Template used for pmie cron.
Default is `pcp/pcp-pmie.cron.erb`.

Default value: 'pcp/pcp-pmie.cron.erb'

##### `include_default_pmlogger`

Data type: `Boolean`

Boolean that determines if default install pmlogger is installed.
Default is `true`.

Default value: `true`

##### `include_default_pmie`

Data type: `Boolean`

Boolean that determines if default install pmie is installed.
Default is `true`.

Default value: `true`

##### `pmlogger_daily_args`

Data type: `String`

Arguments given to pmlogger_daily that is executed via cron.
Default is `'-X xz -x 3'`.

Default value: '-X xz -x 3'

##### `pcp_conf_configs`

Data type: `Hash`

Hash of configs to manage in /etc/pcp.conf.

Default value: {}

##### `pmdas`

Data type: `Hash`

Hash that defines `pcp::pmda` resources.

Default value: {}

## Defined types

### pcp::pmda

Install, enable and optionally configure a PMDA

#### Examples

##### 

```puppet
pcp::pmda { 'nfsclient':
  ensure => 'present',
}
```

#### Parameters

The following parameters are available in the `pcp::pmda` defined type.

##### `ensure`

Data type: `Enum['present', 'absent']`

Ensure property for the PMDA.
Valid values are `'present'` and `'absent'`.
Default is `'present'`.

Default value: 'present'

##### `has_package`

Data type: `Boolean`

Boolean that determines of a package is associated with the PMDA.
Default is `true`.

Default value: `true`

##### `package_name`

Data type: `Optional[String]`

Package name of PMDA.
Default is `pcp-pmda-$name`.

Default value: `undef`

##### `remove_package`

Data type: `Boolean`

Boolean that determines if the package should be removed when `ensure` is `absent`.
Default is `false`.

Default value: `false`

##### `config_path`

Data type: `Optional[Stdlib::Absolutepath]`

Configuration file path for this PMDA.
Default is `/var/lib/pcp/config/${name}/${name}.conf`.

Default value: `undef`

##### `config_content`

Data type: `Optional[String]`

Configuration file content for the PMDA.
Default is `undef`.

Default value: `undef`

##### `config_source`

Data type: `Optional[String]`

Configuration file source for the PMDA.
Default is `undef`.

Default value: `undef`

##### `args`

Data type: `Optional[String]`

Arguments that will be added to pmcd.conf for this PMDA

Default value: `undef`

### pcp::pmie

Configure a pmie

#### Parameters

The following parameters are available in the `pcp::pmie` defined type.

##### `ensure`

Data type: `Enum['present', 'absent']`

The pmie ensure property.
Valid values are `present` and `absent`.
Default is `present`.

Default value: 'present'

##### `hostname`

Data type: `String`

Hostname associated with the pmie.
Default is `'LOCALHOSTNAME'`.

Default value: 'LOCALHOSTNAME'

##### `primary`

Data type: `Boolean`

Boolean that sets if this pmie is primary.
Default is `false`.

Default value: `false`

##### `socks`

Data type: `Boolean`

Boolean that sets if this pmie uses pmsocks.
Default is `false`.

Default value: `false`

##### `log_file`

Data type: `String`

The pmie control log file.  Default is `PCP_LOG_DIR/pmie/LOCALHOSTNAME/pmie.log`

Default value: 'PCP_LOG_DIR/pmie/LOCALHOSTNAME/pmie.log'

##### `args`

Data type: `String`

Args passed to pmie.  Default is an empty string.

Default value: ''

##### `config_path`

Data type: `Optional[Stdlib::Absolutepath]`

Config path for the pmie.  If defined the value is passed as `-c value` to the pmie arguments.  Default is `undef`.

Default value: `undef`

##### `config_content`

Data type: `Optional[String]`

The pmie config contents.  Default is `undef`.

Default value: `undef`

##### `config_source`

Data type: `Optional[String]`

The pmie config source.  Default is `undef`.

Default value: `undef`

### pcp::pmlogger

Configure a pmlogger

#### Parameters

The following parameters are available in the `pcp::pmlogger` defined type.

##### `ensure`

Data type: `Enum['present', 'absent']`

The pmlogger ensure property.
Valid values are `present` and `absent`.
Default is `present`.

Default value: 'present'

##### `hostname`

Data type: `String`

Hostname associated with the pmlogger.
Default is `'LOCALHOSTNAME'`.

Default value: 'LOCALHOSTNAME'

##### `primary`

Data type: `Boolean`

Boolean that sets if this pmlogger is primary.
Default is `false`.

Default value: `false`

##### `socks`

Data type: `Boolean`

Boolean that sets if this pmlogger uses pmsocks.
Default is `false`.

Default value: `false`

##### `log_dir`

Data type: `String`

Log directory for this pmlogger.
Default is `PCP_LOG_DIR/pmlogger/LOCALHOSTNAME`.

Default value: 'PCP_LOG_DIR/pmlogger/LOCALHOSTNAME'

##### `args`

Data type: `String`

Arguments passed to pmlogger.
Default is an empty string.

Default value: ''

##### `config_path`

Data type: `Optional[Stdlib::Absolutepath]`

Config path for the pmlogger.
If defined the value is passed as `-c value` to the pmlogger arguments.
Default is `undef`.

Default value: `undef`

##### `config_content`

Data type: `Optional[String]`

The pmlogger config contents.
Default is `undef`.

Default value: `undef`

##### `config_source`

Data type: `Optional[String]`

The pmlogger config source.
Default is `undef`.

Default value: `undef`

